@@ -1,6 +1,6 @@
 /*
  * Ncview by David W. Pierce.  A visual netCDF file viewer.
- * Copyright (C) 1993-2010 David W. Pierce
+ * Copyright (C) 1993-2024 David W. Pierce
  *
  * This program  is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 3 as
@@ -16,9 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  * David W. Pierce
- * 6259 Caminito Carrena
- * San Diego, CA  92122
- * pierce@cirrus.ucsd.edu
+ * davidwilliampierce@gmail.com
  */
 
 #include "../ncview.includes.h"
@@ -505,9 +503,9 @@ void x_create_colormap( char *name, unsigned char r[256], unsigned char g[256],
         for( i=0; i<options.n_extra_colors; i++ ) {
                 color        = cmaplist->color_list+i;
                 color->flags = DoRed | DoGreen | DoBlue;
-                color->red   = 256*(unsigned int)255;
-                color->green = 256*(unsigned int)255;
-                color->blue  = 256*(unsigned int)255;
+                color->red   = 256*(unsigned int)options.missval_r;
+                color->green = 256*(unsigned int)options.missval_g;
+                color->blue  = 256*(unsigned int)options.missval_b;
                 }
         color        = cmaplist->color_list+1;
         color->flags = DoRed | DoGreen | DoBlue;
